=======================================
Cinder User Documentation (source/user)
=======================================

Introduction:
-------------

This directory is intended to hold any documentation that helps Cinder
end-users.  This can include concept guides, tutorials, step-by-step guides
for using the CLI, etc.  Note that documentation this is focused on
administrative actions should go into 'doc/source/admin'.

The full spec for organization of documentation may be seen in the
`OS Manuals Migration Spec
<https://specs.openstack.org/openstack/docs-specs/specs/pike/os-manuals-migration.html>`.
